==> cbr_website_beta-0.117.12.tar.gz: cbr_website_beta-0.117.12/cbr_website_beta/utils/update_from_s3/Release_Package__via__S3.py <==
from unittest import TestCase

from osbot_utils.decorators.methods.cache_on_self import cache_on_self
from osbot_utils.utils.Env import get_env

import cbr_website_beta
from cbr_website_beta.utils.Version import version
from cbr_website_beta.utils.remote_shell.CBR__Remote_Shell__Copy_Files import \
    CBR__REMOTE_SHELL__FILE_TRANSFER__S3_BUCKET, CBR__REMOTE_SHELL__FILE_TRANSFER__PARENT_FOLDER
from osbot_aws.apis.S3 import S3
from osbot_utils.base_classes.Type_Safe import Type_Safe
from osbot_utils.helpers.trace.Trace_Call import trace_calls
from osbot_utils.testing.Temp_Folder import Temp_Folder
from osbot_utils.testing.Temp_Zip import Temp_Zip
from osbot_utils.utils.Dev import pprint
from osbot_utils.utils.Files import file_move, file_move_to_folder, file_exists, file_not_exists, path_combine, \
    folder_copy, file_name, file_size, files_list, file_contents, file_write
from osbot_utils.utils.Zip import zip_folder, zip_file_list, zip_bytes_file_list, zip_bytes_get_file, \
    zip_bytes_unzip_to_folder

ENV_VAR_NAME__S3_DEV__S3_BUCKET     = 'S3_DEV__BUCKET'
ENV_VAR_NAME__S3_DEV__PARENT_FOLDER = 'S3_DEV__PARENT_FOLDER'
ENV_VAR_NAME__S3_DEV__VERSION       = 'S3_DEV__VERSION'
ENV_VAR_NAME__S3_DEV__PACKAGE_NAME  = 'S3_DEV__PACKAGE_NAME'
DEFAULT_VALUE__PACKAGE_NAME         = 'cbr_website_beta'

class Release_Package__via__S3(Type_Safe):
    zip_file   : str = '/tmp/cbr_website_beta.zip'
    s3         : S3

    # actions

    def unzip_from_s3_to_folder(self, target_folder):
        if self.enabled():
            zip_bytes = self.s3.file_bytes(self.s3_bucket(), self.s3_key())
            zip_bytes_unzip_to_folder(zip_bytes, target_folder)
            return target_folder

    def upload_zip_file_to_s3(self):
        if self.enabled():
            self.s3.file_upload_to_key(file=self.zip_file, bucket=self.s3_bucket(), key=self.s3_key())

    def create_zip_with__cbr_website_beta(self):
        if self.enabled():
            source_folder = cbr_website_beta.path
            ignore_pattern = ['*.pyc', '.DS_Store', '__pycache__', '*.env']
            ignore_pattern.append('__to_delete')

            with Temp_Folder(temp_prefix=self.package_name()) as _:
                destination = path_combine(_.path(), self.package_name())
                folder_copy(source=source_folder, destination=destination, ignore_pattern=ignore_pattern)
                with Temp_Zip(_.path()) as zip_file:
                    zip_file.move_to(self.zip_file)

    @trace_calls(contains=['cbr_website_beta'], show_duration=True, duration_padding=60)
    def download_to_local_temp(self):
        print
        print('========== download_to_local_temp ==========')
        target_folder = '/tmp'
        release_from_s3 = Release_Package__via__S3()
        if release_from_s3.disabled():
            print('release_from_s3 is  disabled, (i.e. S3_DEV__VERSION was not set). Skipping rest of worklfow...')
        else:
            with release_from_s3 as _:
                print(f'   s3_bucket: {_.s3_bucket()}')
                print(f'   s3_key   : {_.s3_key()}')
                # print(f'   s3_bucket: { _.s3_bucket()}')
                if _.s3.file_exists(_.s3_bucket(), _.s3_key()):
                    print('   file exists in S3')
                    _.unzip_from_s3_to_folder(target_folder=target_folder)
                    pprint(f' there were {len(files_list(target_folder))} files extracted')
                    pprint(file_contents('/tmp/cbr_website_cbr/version'))
                    return True
        print('========== download_to_local_temp ==========')
        return False

    def download_zip_file_from_s3__as_bytes(self):
        if self.enabled():
            return self.s3.file_bytes(self.s3_bucket(), self.s3_key())

    # vars
    def enabled(self):
        if self.release_id() and self.s3_bucket():
            return True
        return False

    def disabled(self):
        return self.enabled() is False

    def package_name    (self): return get_env(ENV_VAR_NAME__S3_DEV__PACKAGE_NAME , DEFAULT_VALUE__PACKAGE_NAME                    )
    def s3_bucket       (self): return get_env(ENV_VAR_NAME__S3_DEV__S3_BUCKET    , CBR__REMOTE_SHELL__FILE_TRANSFER__S3_BUCKET    )
    def s3_parent_folder(self): return get_env(ENV_VAR_NAME__S3_DEV__PARENT_FOLDER, CBR__REMOTE_SHELL__FILE_TRANSFER__PARENT_FOLDER)

    @cache_on_self
    def s3_folder(self):
        return f'{self.s3_parent_folder()}/{self.package_name()}'

    @cache_on_self
    def s3_key(self):
        s3_key       = f'{self.s3_folder()}/{self.release_id()}.zip'
        return s3_key

    def release_id(self):
        return get_env(ENV_VAR_NAME__S3_DEV__VERSION)



if __name__ == '__main__':
    Release_Package__via__S3().download_to_local_temp()

==> cbr_website_beta-0.117.14.tar.gz: cbr_website_beta-0.117.14/cbr_website_beta/utils/update_from_s3/Release_Package__via__S3.py <==
import cbr_website_beta
from   cbr_website_beta.utils.remote_shell.CBR__Remote_Shell__Copy_Files  import CBR__REMOTE_SHELL__FILE_TRANSFER__S3_BUCKET, CBR__REMOTE_SHELL__FILE_TRANSFER__PARENT_FOLDER

from   osbot_utils.decorators.methods.cache_on_self                       import cache_on_self
from   osbot_utils.utils.Env                                              import get_env
from   osbot_aws.apis.S3                                                  import S3
from   osbot_utils.base_classes.Type_Safe                                 import Type_Safe
from   osbot_utils.helpers.trace.Trace_Call                               import trace_calls
from   osbot_utils.testing.Temp_Folder                                    import Temp_Folder
from   osbot_utils.testing.Temp_Zip                                       import Temp_Zip
from   osbot_utils.utils.Dev                                              import pprint
from   osbot_utils.utils.Files                                            import path_combine, folder_copy, files_list, file_contents
from   osbot_utils.utils.Zip                                              import zip_bytes_unzip_to_folder

ENV_VAR_NAME__S3_DEV__S3_BUCKET     = 'S3_DEV__BUCKET'
ENV_VAR_NAME__S3_DEV__PARENT_FOLDER = 'S3_DEV__PARENT_FOLDER'
ENV_VAR_NAME__S3_DEV__VERSION       = 'S3_DEV__VERSION'
ENV_VAR_NAME__S3_DEV__PACKAGE_NAME  = 'S3_DEV__PACKAGE_NAME'
DEFAULT_VALUE__PACKAGE_NAME         = 'cbr_website_beta'

class Release_Package__via__S3(Type_Safe):
    zip_file   : str = '/tmp/cbr_website_beta.zip'
    s3         : S3

    # actions

    def unzip_from_s3_to_folder(self, target_folder):
        if self.enabled():
            zip_bytes = self.s3.file_bytes(self.s3_bucket(), self.s3_key())
            zip_bytes_unzip_to_folder(zip_bytes, target_folder)
            return target_folder

    def upload_zip_file_to_s3(self):
        if self.enabled():
            self.s3.file_upload_to_key(file=self.zip_file, bucket=self.s3_bucket(), key=self.s3_key())

    def create_zip_with__cbr_website_beta(self):
        if self.enabled():
            source_folder = cbr_website_beta.path
            ignore_pattern = ['*.pyc', '.DS_Store', '__pycache__', '*.env']
            ignore_pattern.append('__to_delete')

            with Temp_Folder(temp_prefix=self.package_name()) as _:
                destination = path_combine(_.path(), self.package_name())
                folder_copy(source=source_folder, destination=destination, ignore_pattern=ignore_pattern)
                with Temp_Zip(_.path()) as zip_file:
                    zip_file.move_to(self.zip_file)

    #@trace_calls(contains=['cbr_website_beta'], show_duration=True, duration_padding=60)
    def download_to_local_temp(self):
        print
        print('========== download_to_local_temp ==========')
        target_folder = '/tmp'
        release_from_s3 = Release_Package__via__S3()
        if release_from_s3.disabled():
            print('release_from_s3 is disabled, (i.e. S3_DEV__VERSION was not set). Skipping rest of worklfow...')
        else:
            print('    release_from_s3 is enabled')
            with release_from_s3 as _:
                print(f'   s3_bucket: {_.s3_bucket()}')
                print(f'   s3_key   : {_.s3_key()}')
                # print(f'   s3_bucket: { _.s3_bucket()}')
                if _.s3.file_exists(_.s3_bucket(), _.s3_key()):
                    print('   file exists in S3')
                    _.unzip_from_s3_to_folder(target_folder=target_folder)
                    pprint(f' there were {len(files_list(target_folder))} files extracted')
                    pprint(file_contents('/tmp/cbr_website_cbr/version'))
                    return True
                else:
                    print('   ERROR: file did not exists in S3')
        print('========== download_to_local_temp ==========')
        return False

    def download_zip_file_from_s3__as_bytes(self):
        if self.enabled():
            return self.s3.file_bytes(self.s3_bucket(), self.s3_key())

    # vars
    def enabled(self):
        if self.release_id() and self.s3_bucket():
            return True
        return False

    def disabled(self):
        return self.enabled() is False

    def package_name    (self): return get_env(ENV_VAR_NAME__S3_DEV__PACKAGE_NAME , DEFAULT_VALUE__PACKAGE_NAME                    )
    def s3_bucket       (self): return get_env(ENV_VAR_NAME__S3_DEV__S3_BUCKET    , CBR__REMOTE_SHELL__FILE_TRANSFER__S3_BUCKET    )
    def s3_parent_folder(self): return get_env(ENV_VAR_NAME__S3_DEV__PARENT_FOLDER, CBR__REMOTE_SHELL__FILE_TRANSFER__PARENT_FOLDER)

    @cache_on_self
    def s3_folder(self):
        return f'{self.s3_parent_folder()}/{self.package_name()}'

    @cache_on_self
    def s3_key(self):
        s3_key       = f'{self.s3_folder()}/{self.release_id()}.zip'
        return s3_key

    def release_id(self):
        return get_env(ENV_VAR_NAME__S3_DEV__VERSION)



if __name__ == '__main__':
    Release_Package__via__S3().download_to_local_temp()
